@@ -643,7 +643,7 @@ class MyWindow;
 static MyWindow*         window=NULL;
 static Lum::Def::AppInfo info;
 static unsigned long     trackingFileId='G'*256*256*256+'J'*256*256+'T'*256+'\0';
-static unsigned long     trackingFileVersion=1;
+static unsigned long     trackingFileVersion=2;
 
 #if defined(HAVE_LIB_GPS)
 static void cb( struct gps_data_t * data,
@@ -1302,6 +1302,10 @@ public:
       return;
     }
 
+    if (!data.HasFix()) {
+      return;
+    }
+
     double                lon=0.0;
     double                lat=0.0;
     double                alt=0.0;
@@ -1323,8 +1327,8 @@ public:
       tim=data.GetTime();
     }
 
-    unsigned long flon=htonl((unsigned long)rint((lon+90.0)*10000000.0));
-    unsigned long flat=htonl((unsigned long)rint((lat+180.0)*10000000.0));
+    unsigned long flon=htonl((unsigned long)rint((lon+180.0)*10000000.0));
+    unsigned long flat=htonl((unsigned long)rint((lat+90.0)*10000000.0));
     unsigned long falt=htonl((unsigned long)rint(alt*100));
     unsigned long ftim=htonl(tim.GetTime());
 
@@ -1408,7 +1412,8 @@ public:
         continue;
       }
 
-      if (tfv!=trackingFileVersion) {
+      /* We support the current version and version 1 */
+      if (tfv!=trackingFileVersion && tfv!=1) {
         std::cerr << "Wrong file version!" << std::endl;
         continue;
       }
@@ -1477,7 +1482,8 @@ public:
       return;
     }
 
-    if (tfv!=trackingFileVersion) {
+    /* We support the current version and version 1 */
+    if (tfv!=trackingFileVersion && tfv!=1) {
       Lum::Dlg::Msg::ShowOk(GetWindow(),
                             L"Error while opening file!",
                             std::wstring(L"An error occured while opening file:\n")+
@@ -1577,8 +1583,14 @@ public:
         falt=ntohl(falt);
         ftim=ntohl(ftim);
 
-        lon=flon/10000000.0-90.0;
-        lat=flat/10000000.0-180.0;
+        if (tfv==1) {
+          lon=flon/10000000.0-90.0;
+          lat=flat/10000000.0-180.0;
+        }
+        else {
+          lon=flon/10000000.0-180.0;
+          lat=flat/10000000.0-90.0;
+        }
         alt=falt/100;
         time.SetTime(ftim);
 
